@@ -12,11 +12,11 @@ sub match_condition{
 
 =head1 NAME
 
-TaskPipe::InterpParam::MatchHandler_name
+TaskPipe::InterpParam::MatchHandler_name - match handler for the $name parameter variable
 
 =head1 DESCRIPTION
 
-TaskPipe Match handler for the $name parameter value
+TaskPipe Match handler for the $name parameter variable
 
 =head1 AUTHOR
 
