@@ -13,7 +13,7 @@ subtype 'IterateMode',
 
 =head1 NAME
 
-TaskPipe::Role::MooseType_IterateMode
+TaskPipe::Role::MooseType_IterateMode - iterate mode type constraint
 
 =head1 DESCRIPTION
 
