@@ -12,7 +12,7 @@ subtype 'ShellMode',
 
 =head1 NAME
 
-TaskPipe::Role::MooseType_ShellMode
+TaskPipe::Role::MooseType_ShellMode - shell mode type constraint
 
 =head1 DESCRIPTION
 
