@@ -33,7 +33,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Global::Result::Job
+TaskPipe::SchemaTemplate_Global::Result::Job - global schema template for C<job> source
 
 =head1 DESCRIPTION
 
