@@ -23,7 +23,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::Result
+TaskPipe::SchemaTemplate_Project::Result::Result - schema template for the project C<result> table
 
 =head1 DESCRIPTION
 
