@@ -18,7 +18,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::ResultGroup
+TaskPipe::SchemaTemplate_Project::Result::ResultGroup -schema template for the project C<result_group> table
 
 =head1 DESCRIPTION
 
