@@ -21,7 +21,7 @@ __PACKAGE__->add_unique_constraint("xbranch_id", ["xbranch_id", "error_id"]);
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::XBranchError
+TaskPipe::SchemaTemplate_Project::Result::XBranchError - schema template for project C<xbranch_error> table
 
 =head1 DESCRIPTION
 
