@@ -30,6 +30,10 @@ __PACKAGE__->add_columns(
   { data_type => "text", is_nullable => 1 },
   "status",
   { data_type => "varchar", is_nullable => 1, size => 255 },
+  "last_plan_index",
+  { data_type => "bigint", is_nullable => 1 },
+  "last_input_index",
+  { data_type => "bigint", is_nullable => 1 }
 );
 
 
@@ -40,7 +44,7 @@ __PACKAGE__->add_unique_constraint("plan_md5", ["plan_md5", "input_md5"]);
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::Xbranch
+TaskPipe::SchemaTemplate_Project::Result::Xbranch - schema template for project C<xbranch> table
 
 =head1 DESCRIPTION
 
